@@ -26,15 +26,16 @@ def avgglide(x,avlen):
         xout[avlen2:(-avlen+avlen2)] = xout[avlen2:(-avlen+avlen2)] + xwork[i:(-avlen+i)]
     return xout/avlen
 
-
-
 # now, apply weekly cycle to a netcdf file
 ncin = NetCDF.NetCDFFile('input.nc','r')
 ncglide = NetCDF.NetCDFFile('output_glide.nc','w')
 # we can cycle through the netcdf variables that have the 'time'-dimension
 for evar in ncin.variables:
     if ((evar not in ncin.dimensions) & ('time' in ncin.variables[evar].dimensions):
-        pcd.pcd(lambda x: avgglide(x,168),('time',),[{'file' : ncin, 'varname': evar}],[{'file' : ncglide, 'varname': evar}])
+        pcd.pcd(lambda x: avgglide(x,168),\
+                ('time',),\
+                [{'file' : ncin, 'varname': evar}],\
+                [{'file' : ncglide, 'varname': evar}])
 ncglide.close(); print('data written to:', ncglide)
 ncin.close()
 
