@@ -301,7 +301,7 @@ def pcd(func,dnamsel,datin,datout,appenddim = False, maxmembytes = 10000000, for
         vsdin[idatin]['voffset']  = nctemp.variables[datin[idatin]['varname']]._voffset
 
         # dselmarker
-        vsdin[idatin]['dsel'] = [False]*len(vsdin[idatin]['dims'])
+        vsdin[idatin]['dsel'] = [range(e) for e in vsdin[idatin]['dims']]
         if 'dsel' in datin[idatin]:
             # cropped dimensions
             for edcrop in datin[idatin]['dsel']:
@@ -334,7 +334,7 @@ def pcd(func,dnamsel,datin,datout,appenddim = False, maxmembytes = 10000000, for
             nctemp = netcdf_file(ncfn,'r')
             vsdout[idatout]['dims'] = [max(e,1) for e in nctemp.variables[datout[idatout]['varname']].shape]
              # dselmarker
-            vsdout[idatout]['dsel'] = [False]*len(vsdout[idatout])
+            vsdout[idatout]['dsel'] = [range(e) for e in vsdout[idatout]['dims']]
             vsdout[idatout]['itemsize'] = nctemp.variables[datout[idatout]['varname']].itemsize()
             vsdout[idatout]['dtype']=     nctemp.variables[datout[idatout]['varname']]._dtype
             vsdout[idatout]['voffset'] =  nctemp.variables[datout[idatout]['varname']]._voffset
@@ -378,11 +378,13 @@ def pcd(func,dnamsel,datin,datout,appenddim = False, maxmembytes = 10000000, for
                     # In this case, wait for assigning the output dimensions. This actually depends on the specified function
                     dimsstd.insert(idx  ,None)
             else:
-                if ((vsdin[ivsdin]['dims'][idnam] != 1) & (dimsstd[dnamsstd.index(ednam)] != 1) & \
+                if ((len(vsdin[ivsdin]['dsel'][idnam]) != 1) & (dimsstd[dnamsstd.index(ednam)] != 1) & \
                     # we allow non-equal dimension lengths, as long as the dimension is covered/captured by the function
                     # maybe still allow non-equal dimension length not covered by the function????
                     (dimsstd[dnamsstd.index(ednam)] != None) & \
-                    (vsdin[ivsdin]['dims'][idnam] != dimsstd[dnamsstd.index(ednam)])):
+                    (len(vsdin[ivsdin]['dsel'][idnam]) != dimsstd[dnamsstd.index(ednam)])):
+                    print(vsdin[ivsdin]['dims'][idnam])
+                    print(vsdin[ivsdin]['dims'][idnam])
                     raise SomeError("The corresponding output dnamensions (index: "+str(dnamsstd.index(ednam))+") of the input variable "+str(ivsdin)+ " "+ str(idnam)+ " "+" have a different length and not equal to 1.")
                 else:
                     # None means it's considered by the function
@@ -544,10 +546,10 @@ def pcd(func,dnamsel,datin,datout,appenddim = False, maxmembytes = 10000000, for
     
         if vsdout[iddout]['dims'] == None:
             vsdout[iddout]['dims'] = list(dimsstd)
-            vsdout[iddout]['dsel'] = [False]*len(vsdout[iddout]['dims']) # Added for consistency with input dimensions. As output dimension, it is not really used.
             # overwrite dimensions with the function output dimensions
             for irefdfuncout,erefdfuncout in enumerate(arefdfuncout[iddout]):
                 vsdout[iddout]['dims'][erefdfuncout] = ddout[iddout].shape[irefdfuncout]
+            vsdout[iddout]['dsel'] = [range(e) for e in vsdout[iddout]['dims']] # Added for consistency with input dimensions. As output dimension, it is not really used.
     
         if vsdout[iddout]['dtype'] == None:
             # output netcdf variable does not exist... creating
@@ -922,7 +924,7 @@ def pcd(func,dnamsel,datin,datout,appenddim = False, maxmembytes = 10000000, for
     rwchunksizein = [1]*len(vsdin)
     for ivsdin,evsdin in enumerate(vsdin):
         idim = len(vsdin[ivsdin]['dims'])-1
-        while ((idim in arefdnoiterin[ivsdin]) & (idim >= 0) & (vsdin[ivsdin]['dsel'][idim] == False) & ((type(datin[ivsdin]['file']).__name__  != 'list') | (idim != 0))):
+        while ((idim in arefdnoiterin[ivsdin]) & (idim >= 0) & (vsdin[ivsdin]['dsel'][idim] == range(vsdin[ivsdin]['dims'][idim])) & ((type(datin[ivsdin]['file']).__name__  != 'list') | (idim != 0))):
             # The inner dimensions just have to be referenced so not in correct order.  We know that they will be read in the correct order in the end
             rwchunksizein[ivsdin] = rwchunksizein[ivsdin]*vsdin[ivsdin]['dims'][idim]
             idim = idim - 1
